@@ -22,11 +22,12 @@ DEALINGS IN THE SOFTWARE.
 
 from __future__ import annotations
 
-from typing import Literal, TypedDict
+from typing import Literal
 
+from .._typed_dict import NotRequired, TypedDict
 from .snowflake import Snowflake
 
-AutoModTriggerType = Literal[1, 2, 3, 4]
+AutoModTriggerType = Literal[1, 2, 3, 4, 5]
 
 AutoModEventType = Literal[1]
 
@@ -37,7 +38,10 @@ AutoModKeywordPresetType = Literal[1, 2, 3]
 
 class AutoModTriggerMetadata(TypedDict, total=False):
     keyword_filter: list[str]
+    regex_patterns: list[str]
     presets: list[AutoModKeywordPresetType]
+    allow_list: list[str]
+    mention_total_limit: int
 
 
 class AutoModActionMetadata(TypedDict, total=False):
@@ -64,13 +68,10 @@ class AutoModRule(TypedDict):
     exempt_channels: list[Snowflake]
 
 
-class _CreateAutoModRuleOptional(TypedDict, total=False):
-    enabled: bool
-    exempt_roles: list[Snowflake]
-    exempt_channels: list[Snowflake]
-
-
-class CreateAutoModRule(_CreateAutoModRuleOptional):
+class CreateAutoModRule(TypedDict):
+    enabled: NotRequired[bool]
+    exempt_roles: NotRequired[list[Snowflake]]
+    exempt_channels: NotRequired[list[Snowflake]]
     name: str
     event_type: AutoModEventType
     trigger_type: AutoModTriggerType
