@@ -483,15 +483,15 @@ class View:
             self.__cancel_callback = None
 
     def is_finished(self) -> bool:
-        """:class:`bool`: Whether the view has finished interacting."""
+        """Whether the view has finished interacting."""
         return self.__stopped.done()
 
     def is_dispatching(self) -> bool:
-        """:class:`bool`: Whether the view has been added for dispatching purposes."""
+        """Whether the view has been added for dispatching purposes."""
         return self.__cancel_callback is not None
 
     def is_persistent(self) -> bool:
-        """:class:`bool`: Whether the view is set up as persistent.
+        """Whether the view is set up as persistent.
 
         A persistent view has all their components with a set ``custom_id`` and
         a :attr:`timeout` set to ``None``.
@@ -568,7 +568,7 @@ class ViewStore:
 
     def __verify_integrity(self):
         to_remove: list[tuple[int, int | None, str]] = []
-        for (k, (view, _)) in self._views.items():
+        for k, (view, _) in self._views.items():
             if view.is_finished():
                 to_remove.append(k)
 
