@@ -2,11 +2,15 @@
     This module contains definitions regarding miscellaneous
     items that can appear in multiple modules
 """
-from typing import Coroutine, Callable, Any, Optional
+from typing import Coroutine, Callable, Any, Dict, Optional, Union
 from asyncio import Semaphore
 from functools import wraps
 from inspect import getfullargspec
 from copy import copy
+from typeguard import typechecked
+
+import signal
+import sys
 
 ###############################
 # Safe access functions
@@ -93,7 +97,35 @@ async def _update(obj: Any, *, init_options: dict = {}, **kwargs):
 ###########################
 # Decorators
 ###########################
-def _async_safe(semaphore: str, amount: Optional[int]=1) -> Callable:
+def sigint_handler(signum, frame):
+    pass
+
+def _async_cancellation_safe(func: Callable):
+    """
+    Decorator that wraps coroutine and prevents the interrupt signal.
+
+    Parameters
+    ------------
+    func: Callable
+        Function which returns a coroutine.
+    """
+    @wraps(func)
+    async def wrapper(*args, **kwargs):
+        old_handler = signal.signal(signal.SIGINT, sigint_handler)
+        return_ = await func(*args, **kwargs)
+        if old_handler != sigint_handler:
+            # This can happen since we have an await statement.
+            # If we create 2 tasks Task1 and Task2 and Task1 finishes before Task2,
+            # then Task2 would eventually set the signal handler back to sigint_handler
+            # instead to the original system handler
+            signal.signal(signal.SIGINT, old_handler)
+        
+        return return_
+
+    return wrapper
+
+@typechecked
+def _async_safe(semaphore: Union[str, Semaphore], amount: Optional[int]=1) -> Callable:
     """
     Function that returns a safety decorator, which uses the :strong:`semaphore` parameter
     as a safety mechanism.
@@ -117,28 +149,74 @@ def _async_safe(semaphore: str, amount: Optional[int]=1) -> Callable:
         The ``semaphore`` parameter is not a string describing the semaphore attribute of a table.
     """
 
-    def __safe_access(coroutine: Coroutine) -> Coroutine:
+    def __safe_access(coroutine: Union[Coroutine, Callable]) -> Coroutine:
         """
         Decorator that returns a method wrapper Coroutine that utilizes a
         asyncio semaphore to assure safe asynchronous operations.
         """
-        @wraps(coroutine)
-        async def wrapper(self, *args, **kwargs):
-            sem: Semaphore = getattr(self, semaphore)
-            for i in range(amount):
-                await sem.acquire()
+        if isinstance(semaphore, str):
+            async def wrapper(self, *args, **kwargs):
+                sem: Semaphore = getattr(self, semaphore)
+                for i in range(amount):
+                    await sem.acquire()
+                try:
+                    result = await coroutine(self, *args, **kwargs)
+                finally:
+                    for i in range(amount):
+                        sem.release()
 
-            result = await coroutine(self, *args, **kwargs)
+                return result
+        else:
+            async def wrapper(*args, **kwargs):
+                for i in range(amount):
+                    await semaphore.acquire()
+                try:
+                    result = await coroutine(*args, **kwargs)
+                finally:
+                    for i in range(amount):
+                        semaphore.release()
 
-            for i in range(amount):
-                sem.release()
+                return result
 
-            return result
+        return wraps(coroutine)(wrapper)
 
-        return wrapper
-
-
-    if not isinstance(semaphore, str):
-        raise TypeError("semaphore parameter must be an attribute name of the asyncio semaphore inside the object")
 
     return __safe_access
+
+
+# Documentation
+DOCUMENTATION_MODE = "DOCUMENTATION" in sys.argv
+if DOCUMENTATION_MODE:
+    doc_titles: Dict[str, list] = {}
+
+def doc_category(cat: str, manual: Optional[bool] = False, path: Optional[str]=None):
+    """
+    Used for marking under which category this should
+    be put when auto generating documentation.
+
+    Parameters
+    ------------
+    cat: str
+        The name of the category to put this in.
+    manual: Optional[bool]
+        Should documentation be manually generated
+    path: Optional[str]
+        Custom path to the object.
+
+    Returns
+    ----------
+    Decorator
+        Returns decorator which marks the object
+        to the category.
+    """
+    def _category(item):
+        if DOCUMENTATION_MODE:
+            doc_titles[cat].append((item, manual, path))
+        return item
+
+    if DOCUMENTATION_MODE:
+        if cat not in doc_titles:
+            doc_titles[cat] = []
+
+    return _category
+
